summaryrefslogtreecommitdiff
path: root/modules/block
diff options
context:
space:
mode:
authorDries Buytaert <dries@buytaert.net>2010-05-09 13:57:59 +0000
committerDries Buytaert <dries@buytaert.net>2010-05-09 13:57:59 +0000
commit1cadf35f0352f2bc96eb3786227581c331d1fd6b (patch)
tree4dc694285d9172d938d2023f2430fb3c323319a2 /modules/block
parent4d795f32474767aa6ed71add92405b6b30d9e498 (diff)
downloadbrdo-1cadf35f0352f2bc96eb3786227581c331d1fd6b.tar.gz
brdo-1cadf35f0352f2bc96eb3786227581c331d1fd6b.tar.bz2
- Patch #791264 by JacobSingh: block configuration screens using tableDrag throws JS error in block.js (row undefined).
Diffstat (limited to 'modules/block')
-rw-r--r--modules/block/block.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/modules/block/block.js b/modules/block/block.js
index 4647ee4e0..be284bfc1 100644
--- a/modules/block/block.js
+++ b/modules/block/block.js
@@ -64,8 +64,8 @@ Drupal.behaviors.blockSettingsSummary = {
*/
Drupal.behaviors.blockDrag = {
attach: function (context, settings) {
- // tableDrag is required for this behavior.
- if (typeof Drupal.tableDrag == 'undefined') {
+ // tableDrag is required and we should be on the blocks admin page.
+ if (typeof Drupal.tableDrag == 'undefined' || typeof Drupal.tableDrag.blocks == 'undefined') {
return;
}